@@ -18,7 +18,7 @@ import requests
 from sensemapi import compat, paths
 from sensemapi.errors import *
 from sensemapi.reprobject import ReprObject
-from sensemapi.senseBox import senseBox
+from sensemapi.senseBox import senseBox, senseBoxCollection
 from sensemapi.senseBoxSensorData import senseBoxSensorData
 from sensemapi.utils import *
 
@@ -600,6 +600,108 @@ class SenseMapClient(ReprObject):
         except compat.JSONDecodeError:
             return senseBoxSensorData.from_csv(io.StringIO(response.text))
 
+    def get_boxes(
+        self,
+        bbox=None,
+        from_date=None,
+        to_date=None,
+        phenomenon=None,
+        grouptag=None,
+        minimal=False,
+        exposure=None,
+    ):
+        """
+        Get all senseBoxes that match certain criteria.
+        Description: https://docs.opensensemap.org/#api-Boxes-getBox
+
+
+        Args:
+            bbox (list): the coordinates of the area of interest in the
+                following order: longitude southwest,
+                latitude southwest, longitude northeast,
+                latitude northeast
+            from_date (datetime.datetime, optional): if to_date is
+                provided, this is the beginning date of boxes data
+                (if to_date is not provided, boxes that submitted data
+                around this time, +/- 4 hours, are returned)
+            to_date (datetime.datetime, optional): if from_date is
+                provided, this is the ending date of boxes(if from_date
+                 is not provided, boxes that submitted data around
+                 this time, +/- 4 hours, are returned)
+            phenomenon (str, optional): A sensor phenomenon
+                (determined by sensor name) such as temperature,
+                humidity or UV intensity. Requirement: from_date or
+                to_date must at least be provided, otherwise
+                'phenomenon' will be ignored.
+            grouptag (set, optional): only return boxes with this
+                grouptag, allows to specify multiple strings in one
+                list
+            minimal (bool, optional): if specified, only a minimal
+                set of box metadata is returned for fast response.
+                Default is ``False``
+            exposure (list, optional): Only include boxes with this
+                exposure. Allows to specify multiple strings in one
+                list. Allowed values: "indoor",
+                    "outdoor", "mobile", "unknown"
+        Returns:
+            senseBoxCollection : the API-Response converted to
+            SenseBox-Objects stored in a List
+        """
+        assert bbox, "bbox must  be defined"
+
+        d = {"bbox": ",".join(map(str, map(float, bbox)))}
+
+        dates = list()
+        if to_date:
+            dates.append(from_date)
+            if from_date:
+                dates.append(to_date)
+
+        if dates:
+            d["date"] = ",".join(map(date2str, dates))
+        if phenomenon is not None:
+            if not d.get("date"):
+                raise ValueError(
+                    "Missing Value to_date or from_date required for "
+                    "usage of phenomenon"
+                )
+        d["phenomenon"] = phenomenon
+        if grouptag is not None:
+            d["grouptag"] = ",".join(
+                map(
+                    str, (grouptag,) if isinstance(grouptag, str) else grouptag
+                )
+            )
+        d["minimal"] = json.dumps(minimal)
+        if exposure is not None:
+            d["exposure"] = ",".join(
+                map(
+                    str, (exposure,) if isinstance(exposure, str) else exposure
+                )
+            )
+
+        logger.debug(
+            "Sending GET request with parameters:\n{}".format(pretty_json(d))
+        )
+
+        response = self.request(
+            "get", urljoin(self.api, paths.BOXES), params=d
+        )
+
+        response_json = response.json()
+
+        if response.status_code == 200:
+            return senseBoxCollection(
+                map(senseBox.from_api_json, response_json)
+            )
+        else:
+            message = response_json
+            raise OpenSenseMapAPIError(
+                "Could not retreive boxes{}".format(
+                    ": {}".format(message) if message else ""
+                )
+            )
+
     def __del__(self):
         """
         Class destructor. Calls :meth:`requests.Session.close` on
